@@ -5,15 +5,14 @@
 import os, sys, ast, json, glob, platform, subprocess, random, time
 
 # inc imports.
-import cl1, syst3m
-from fil3s import *
-from r3sponse import r3sponse
+import syst3m
+from dev0s import *
 
 # source.
 ALIAS = "imag3"
-SOURCE_PATH = syst3m.defaults.source_path(__file__, back=3)
-OS = syst3m.defaults.operating_system(supported=["macos", "linux"])
-syst3m.defaults.alias(alias=ALIAS, executable=f"{SOURCE_PATH}")
+SOURCE_PATH = Defaults.source_path(__file__, back=3)
+OS = Defaults.operating_system(supported=["macos", "linux"])
+Defaults.alias(alias=ALIAS, executable=f"{SOURCE_PATH}")
 
 # universal variables.
 OWNER = os.environ.get("USER")
